@@ -18,11 +18,11 @@ if "-lz":
 if "-lpng":
 	mylibs.append('png')
 
-if "-lungif":
+if "-lgif":
 	mylibs.append("ungif")
 
 
-setup(name = "mingc", version = "0.4.4",
+setup(name = "mingc", version = "0.4.5",
       package_dir = {'': srcdir},
       py_modules = ['ming', 'mingc'],
       ext_modules = [Extension("_mingc", ["%s/ming_wrap.c" %srcdir],
