@@ -17,7 +17,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-/* $Id: mp3.c,v 1.21 2008/07/22 20:38:42 krechert Exp $ */
+/* $Id$ */
 
 #include "libming.h"
 #include "input.h"
@@ -219,6 +219,13 @@ int getMP3Flags(SWFInput input, byte *flags)
 	return start;	
 }
 
+/*
+ * Read at most the wanted number of samples from the input mp3 stream
+ * The stream read pointer is advanced.
+ * The actual number of samples read is written in *wanted and their
+ * total length is returned.
+ * If *wanted is < 0 read all there is in the stream.
+ */
 int getMP3Samples(SWFInput input, int flags, int *wanted)
 {
 	int frameSize, length;
@@ -243,10 +250,11 @@ int getMP3Samples(SWFInput input, int flags, int *wanted)
 	{
 		length = nextMP3Frame(input);
 		if(length <= 0)
-			break;	
+			break; /* EOF */
 		totalLength += length;
 		numSamples += frameSize;
 	}
+
 	*wanted = numSamples;			
 	return totalLength;
 }
