@@ -17,7 +17,7 @@
 		Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA	02111-1307	USA
 */
 
-/* $Id: text.c,v 1.43 2009/12/01 20:09:44 strk Exp $ */
+/* $Id$ */
 
 #ifndef __C2MAN__
 #include <stdlib.h>
@@ -538,13 +538,13 @@ SWFText_scaledMoveTo(SWFText text, int x, int y)
 	if (NULL == textRecord)
 		return;
 
-	if ( x != 0 )
+	if ( x != 0 || (text->initialRecord && text->initialRecord->string))
 	{
 		textRecord->flags |= SWF_TEXT_HAS_X;
 		textRecord->x = x;
 	}
 
-	if ( y != 0 )
+	if ( y != 0 || (text->initialRecord && text->initialRecord->string))
 	{
 		textRecord->flags |= SWF_TEXT_HAS_Y;
 		textRecord->y = y;
@@ -660,22 +660,17 @@ SWFTextRecord_computeAdvances(SWFTextRecord textRecord)
 		memset(textRecord->advance, 0, sizeof(int) * len);
 	}
 
-	glyph = SWFFont_findGlyphCode(font, widestring[0]);
-
 	for ( i=0; i<len; ++i )
 	{
 		int adv;
-		unsigned short nextglyph;
-
-		adv = SWFFont_getCharacterAdvance(font, (unsigned short)glyph);
+		glyph = SWFFont_findGlyphCode(font, widestring[i]);
+		adv = SWFFont_getCharacterAdvance(font, glyph);
 		adv += textRecord->spacing;
 
 		/* get kerning from font's kern table */
 
-		if ( i < len-1 )
-		{	nextglyph = SWFFont_findGlyphCode(font, widestring[i+1]);
-			adv += SWFFont_getCharacterKern(font, glyph, nextglyph);
-			glyph = nextglyph;
+		if ( i < len-1 ) {
+			adv += SWFFont_getCharacterKern(font, widestring[i], widestring[i+1]);
 		}
 
 		if ( textRecord->advance != NULL )
