@@ -22,6 +22,9 @@
 
 	$d = $m->add($b);
 	$d->moveTo(50, 100);
+	
+	$m->addExport($b, "ButtonExport");
+	$m->writeExports();
 
 	$m->nextFrame;
 	$m->save("test02.swf");
