@@ -2,7 +2,7 @@
 
 static char *test = "test01";
 
-main()
+int main()
 {
 SWFMovie m;
 
