@@ -16,6 +16,10 @@ $t->setHeight(20);
 $t->setColor(0x00, 0x00, 0x00, 0xff);
 $t->moveTo(10, 20); 
 $t->addString("abc");
+$t->moveTo(0, 40); 
+$t->addString("bca");
+$t->moveTo(60, 0); 
+$t->addString("cab");
 
 $m->add($t);
 $m->nextFrame(); 
