@@ -8,7 +8,6 @@ $mediadir="$ARGV[0]/../Media";
 $m = new SWF::Movie();
 
 $f2 = new SWF::Font($mediadir."/font01.fdb");
-$f3 = new SWF::Font($mediadir."/test.ttf");
 
 # SWF_DEFINETEXT2 
 $t = new SWF::Text(2);
@@ -17,6 +16,10 @@ $t->setHeight(20);
 $t->setColor(0x00, 0x00, 0x00, 0xff);
 $t->moveTo(10, 20);
 $t->addString("abc");
+$t->moveTo(0, 40);
+$t->addString("bca");
+$t->moveTo(60, 0);
+$t->addString("cab");
 
 # SWF_PLACEOBJECT2 
 $i1 = $m->add($t);
