@@ -149,19 +149,18 @@ sub doswftest($$$$)
 				chop;
 				$ENV{'PYTHONPATH'} .= ":".$_;
 			}
+			$testbuilder = "$ENV{'PYTHON'} $testbuilder";
 		}
 
 		elsif($binding eq 'php')
 		{
-			# TODO: have the .phpx file passed instead !
-			$testbuilder = "php -n -d extension_dir=$TOP_BUILDDIR/php_ext/.libs -d extension=ming.so $testbuilder";
+			$testbuilder = "$ENV{'PHP'} -n -d extension_dir=$TOP_BUILDDIR/php_ext/.libs -d extension=ming.so $testbuilder";
 		}
 
 		elsif($binding eq 'perl')
 		{
-			# Set the proper PERL5LIB
-			# (BUILDDIR contains both SWF.pm and SWF.so)
-			$ENV{'PERL5LIB'}=$TOP_BUILDDIR."/perl_ext/blib/arch/auto/SWF/:".$TOP_BUILDDIR."/perl_ext/blib/lib";
+			# Set the proper blib path
+			$testbuilder = "$ENV{'PERL'} -w -Mblib='${TOP_BUILDDIR}/perl_ext/blib' $testbuilder";
 		}
 	}
 	else
