@@ -17,7 +17,6 @@ outputTrailer (struct Movie *m)
 void
 outputBlock (int type, SWF_Parserstruct * blockp, FILE* f)
 {
-	static int fontnum=0;
 	FILE *out;
 	char name[256];
 	int skipBytes, ret;
@@ -25,9 +24,16 @@ outputBlock (int type, SWF_Parserstruct * blockp, FILE* f)
 	int length = blockp->length;
 	char *buf;
 
-	if ( type != SWF_DEFINEFONT2 ) return;
+	switch ( type ) {
+		case SWF_DEFINEFONT:
+		case SWF_DEFINEFONT2:
+		case SWF_DEFINEFONT3:
+			break;
+		default:
+			return;
+	}
 
-	sprintf(name, "font%i.fdb", fontnum++);
+	sprintf(name, "font%i.fdb", blockp->block.SWF_DEFINEFONT2.FontID);
 
 
   	out=fopen(name,"wb");
@@ -47,7 +53,7 @@ outputBlock (int type, SWF_Parserstruct * blockp, FILE* f)
 		skipBytes += 4;
 
 	fseek(f, offset + skipBytes, SEEK_SET); /* skip FontId (UI16) */
-	length -= skipBytes;
+	length -= 2;				/* sub FontId (UI16) only */
 	
 	printf("Writing font '%s' to file '%s' (%i bytes)... ",
 		blockp->block.SWF_DEFINEFONT2.FontName, name, length+4); /* +4 for 'fdb0' header */
